@@ -76,7 +76,7 @@ sub on_generate
     my $c = Chronicle::load_template("index.rss");
     $c->param( top => $config->{ 'top' } );
     $c->param( entries => $entries ) if ($entries);
-    open( my $handle, ">:utf8", "$config->{'output'}/index.rss" ) or
+    open( my $handle, ">:encoding(UTF-8)", "$config->{'output'}/index.rss" ) or
       die "Failed to open";
     print $handle $c->output();
     close($handle);
