@@ -43,12 +43,6 @@ sub on_initiate
     my $dbh    = $args{ 'dbh' };
     my $config = $args{ 'config' };
 
-    #
-    #  Disabled.
-    #
-    return;
-
-
     #
     #  This is how you'd update the global config
     #
